from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.UI.Xaml.Interop
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
class BindableVectorChangedEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{624cd4e1-d007-43b1-9c03-af4d3e6258c4}')
    @winrt_commethod(3)
    def Invoke(self, vector: win32more.Windows.UI.Xaml.Interop.IBindableObservableVector, e: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
class IBindableIterable(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Interop.IBindableIterable'
    _iid_ = Guid('{036d2c08-df29-41af-8aa2-d774be62ba6f}')
    @winrt_commethod(6)
    def First(self) -> win32more.Windows.UI.Xaml.Interop.IBindableIterator: ...
class IBindableIterator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Interop.IBindableIterator'
    _iid_ = Guid('{6a1d6c07-076d-49f2-8314-f52c9c9a8331}')
    @winrt_commethod(6)
    def get_Current(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def get_HasCurrent(self) -> Boolean: ...
    @winrt_commethod(8)
    def MoveNext(self) -> Boolean: ...
    Current = property(get_Current, None)
    HasCurrent = property(get_HasCurrent, None)
class IBindableObservableVector(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Interop.IBindableObservableVector'
    _iid_ = Guid('{fe1eb536-7e7f-4f90-ac9a-474984aae512}')
    @winrt_commethod(6)
    def add_VectorChanged(self, handler: win32more.Windows.UI.Xaml.Interop.BindableVectorChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_VectorChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    VectorChanged = event()
class IBindableVector(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Interop.IBindableVector'
    _iid_ = Guid('{393de7de-6fd0-4c0d-bb71-47244a113e93}')
    @winrt_commethod(6)
    def GetAt(self, index: UInt32) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def get_Size(self) -> UInt32: ...
    @winrt_commethod(8)
    def GetView(self) -> win32more.Windows.UI.Xaml.Interop.IBindableVectorView: ...
    @winrt_commethod(9)
    def IndexOf(self, value: win32more.Windows.Win32.System.WinRT.IInspectable, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_commethod(10)
    def SetAt(self, index: UInt32, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(11)
    def InsertAt(self, index: UInt32, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(12)
    def RemoveAt(self, index: UInt32) -> Void: ...
    @winrt_commethod(13)
    def Append(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(14)
    def RemoveAtEnd(self) -> Void: ...
    @winrt_commethod(15)
    def Clear(self) -> Void: ...
    Size = property(get_Size, None)
class IBindableVectorView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Interop.IBindableVectorView'
    _iid_ = Guid('{346dd6e7-976e-4bc3-815d-ece243bc0f33}')
    @winrt_commethod(6)
    def GetAt(self, index: UInt32) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def get_Size(self) -> UInt32: ...
    @winrt_commethod(8)
    def IndexOf(self, value: win32more.Windows.Win32.System.WinRT.IInspectable, index: POINTER(UInt32)) -> Boolean: ...
    Size = property(get_Size, None)
class INotifyCollectionChanged(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Interop.INotifyCollectionChanged'
    _iid_ = Guid('{28b167d5-1a31-465b-9b25-d5c3ae686c40}')
    @winrt_commethod(6)
    def add_CollectionChanged(self, handler: win32more.Windows.UI.Xaml.Interop.NotifyCollectionChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_CollectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CollectionChanged = event()
class INotifyCollectionChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Interop.INotifyCollectionChangedEventArgs'
    _iid_ = Guid('{4cf68d33-e3f2-4964-b85e-945b4f7e2f21}')
    @winrt_commethod(6)
    def get_Action(self) -> win32more.Windows.UI.Xaml.Interop.NotifyCollectionChangedAction: ...
    @winrt_commethod(7)
    def get_NewItems(self) -> win32more.Windows.UI.Xaml.Interop.IBindableVector: ...
    @winrt_commethod(8)
    def get_OldItems(self) -> win32more.Windows.UI.Xaml.Interop.IBindableVector: ...
    @winrt_commethod(9)
    def get_NewStartingIndex(self) -> Int32: ...
    @winrt_commethod(10)
    def get_OldStartingIndex(self) -> Int32: ...
    Action = property(get_Action, None)
    NewItems = property(get_NewItems, None)
    NewStartingIndex = property(get_NewStartingIndex, None)
    OldItems = property(get_OldItems, None)
    OldStartingIndex = property(get_OldStartingIndex, None)
class INotifyCollectionChangedEventArgsFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Interop.INotifyCollectionChangedEventArgsFactory'
    _iid_ = Guid('{b30c3e3a-df8d-44a5-9a38-7ac0d08ce63d}')
    @winrt_commethod(6)
    def CreateInstanceWithAllParameters(self, action: win32more.Windows.UI.Xaml.Interop.NotifyCollectionChangedAction, newItems: win32more.Windows.UI.Xaml.Interop.IBindableVector, oldItems: win32more.Windows.UI.Xaml.Interop.IBindableVector, newIndex: Int32, oldIndex: Int32, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Interop.NotifyCollectionChangedEventArgs: ...
class NotifyCollectionChangedAction(Enum, Int32):
    Add = 0
    Remove = 1
    Replace = 2
    Move = 3
    Reset = 4
class NotifyCollectionChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Interop.INotifyCollectionChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Interop.NotifyCollectionChangedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 5:
            super().__init__(move=win32more.Windows.UI.Xaml.Interop.NotifyCollectionChangedEventArgs.CreateInstanceWithAllParameters(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstanceWithAllParameters(cls: win32more.Windows.UI.Xaml.Interop.INotifyCollectionChangedEventArgsFactory, action: win32more.Windows.UI.Xaml.Interop.NotifyCollectionChangedAction, newItems: win32more.Windows.UI.Xaml.Interop.IBindableVector, oldItems: win32more.Windows.UI.Xaml.Interop.IBindableVector, newIndex: Int32, oldIndex: Int32, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Interop.NotifyCollectionChangedEventArgs: ...
    @winrt_mixinmethod
    def get_Action(self: win32more.Windows.UI.Xaml.Interop.INotifyCollectionChangedEventArgs) -> win32more.Windows.UI.Xaml.Interop.NotifyCollectionChangedAction: ...
    @winrt_mixinmethod
    def get_NewItems(self: win32more.Windows.UI.Xaml.Interop.INotifyCollectionChangedEventArgs) -> win32more.Windows.UI.Xaml.Interop.IBindableVector: ...
    @winrt_mixinmethod
    def get_OldItems(self: win32more.Windows.UI.Xaml.Interop.INotifyCollectionChangedEventArgs) -> win32more.Windows.UI.Xaml.Interop.IBindableVector: ...
    @winrt_mixinmethod
    def get_NewStartingIndex(self: win32more.Windows.UI.Xaml.Interop.INotifyCollectionChangedEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_OldStartingIndex(self: win32more.Windows.UI.Xaml.Interop.INotifyCollectionChangedEventArgs) -> Int32: ...
    Action = property(get_Action, None)
    NewItems = property(get_NewItems, None)
    NewStartingIndex = property(get_NewStartingIndex, None)
    OldItems = property(get_OldItems, None)
    OldStartingIndex = property(get_OldStartingIndex, None)
class NotifyCollectionChangedEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ca10b37c-f382-4591-8557-5e24965279b0}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Interop.NotifyCollectionChangedEventArgs) -> Void: ...
class TypeKind(Enum, Int32):
    Primitive = 0
    Metadata = 1
    Custom = 2
class TypeName(Structure):
    Name: WinRT_String
    Kind: win32more.Windows.UI.Xaml.Interop.TypeKind


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.ParentalControls
ARRAY_SEP_CHAR: UInt32 = 9
WPCCHANNEL: UInt32 = 16
WPC_SETTINGS_LOCATE: UInt32 = 20
WPC_SETTINGS_MODIFY: UInt32 = 21
WPC_APP_LAUNCH: UInt32 = 22
WPC_SYSTEM: UInt32 = 23
WPC_WEB: UInt32 = 24
WPCPROV_TASK_SettingChange: UInt32 = 1
WPCPROV_TASK_GameStart: UInt32 = 2
WPCPROV_TASK_UrlVisit: UInt32 = 3
WPCPROV_TASK_EmailReceived: UInt32 = 4
WPCPROV_TASK_EmailSent: UInt32 = 5
WPCPROV_TASK_MediaPlayback: UInt32 = 6
WPCPROV_TASK_IMInvitation: UInt32 = 7
WPCPROV_TASK_IMJoin: UInt32 = 8
WPCPROV_TASK_IMLeave: UInt32 = 9
WPCPROV_TASK_FileDownload: UInt32 = 10
WPCPROV_TASK_IMFeature: UInt32 = 11
WPCPROV_TASK_Custom: UInt32 = 13
WPCPROV_TASK_EmailContact: UInt32 = 14
WPCPROV_TASK_IMContact: UInt32 = 15
WPCPROV_TASK_AppBlocked: UInt32 = 16
WPCPROV_TASK_AppOverride: UInt32 = 17
WPCPROV_TASK_WebOverride: UInt32 = 18
WPCPROV_TASK_WebsiteVisit: UInt32 = 19
WPCPROV_TASK_Application: UInt32 = 20
WPCPROV_TASK_ComputerUsage: UInt32 = 21
WPCPROV_TASK_ContentUsage: UInt32 = 22
WPCPROV_KEYWORD_WPC: UInt32 = 16
WPCPROV_KEYWORD_ThirdParty: UInt32 = 32
WPCEVENT_SYS_SETTINGCHANGE_value: UInt32 = 1
WPCEVENT_GAME_START_value: UInt32 = 2
WPCEVENT_WEB_URLVISIT_value: UInt32 = 3
WPCEVENT_EMAIL_RECEIVED_value: UInt32 = 4
WPCEVENT_EMAIL_SENT_value: UInt32 = 5
WPCEVENT_MEDIA_PLAYBACK_value: UInt32 = 6
WPCEVENT_IM_INVITATION_value: UInt32 = 7
WPCEVENT_IM_JOIN_value: UInt32 = 8
WPCEVENT_IM_LEAVE_value: UInt32 = 9
WPCEVENT_WEB_FILEDOWNLOAD_value: UInt32 = 10
WPCEVENT_IM_FEATURE_value: UInt32 = 11
WPCEVENT_CUSTOM_value: UInt32 = 13
WPCEVENT_EMAIL_CONTACT_value: UInt32 = 14
WPCEVENT_IM_CONTACT_value: UInt32 = 15
WPCEVENT_SYSTEM_APPBLOCKED_value: UInt32 = 16
WPCEVENT_APPOVERRIDE_value: UInt32 = 17
WPCEVENT_WEBOVERRIDE_value: UInt32 = 18
WPCEVENT_WEB_WEBSITEVISIT_value: UInt32 = 19
WPCEVENT_APPLICATION_value: UInt32 = 20
WPCEVENT_COMPUTERUSAGE_value: UInt32 = 21
WPCEVENT_CONTENTUSAGE_value: UInt32 = 22
MSG_Keyword_WPC: Int32 = 268435461
MSG_Keyword_ThirdParty: Int32 = 268435462
MSG_Opcode_Locate: Int32 = 805306388
MSG_Opcode_Modify: Int32 = 805306389
MSG_Opcode_Launch: Int32 = 805306390
MSG_Opcode_System: Int32 = 805306391
MSG_Opcode_Web: Int32 = 805306392
MSG_Task_SettingChange: Int32 = 1879048193
MSG_Task_GameStart: Int32 = 1879048194
MSG_Task_UrlVisit: Int32 = 1879048195
MSG_Task_EmailReceived: Int32 = 1879048196
MSG_Task_EmailSent: Int32 = 1879048197
MSG_Task_MediaPlayback: Int32 = 1879048198
MSG_Task_IMInvitation: Int32 = 1879048199
MSG_Task_IMJoin: Int32 = 1879048200
MSG_Task_IMLeave: Int32 = 1879048201
MSG_Task_FileDownload: Int32 = 1879048202
MSG_Task_IMFeature: Int32 = 1879048203
MSG_Task_Custom: Int32 = 1879048205
MSG_Task_EmailContact: Int32 = 1879048206
MSG_Task_IMContact: Int32 = 1879048207
MSG_Task_AppBlocked: Int32 = 1879048208
MSG_Task_AppOverride: Int32 = 1879048209
MSG_Task_WebOverride: Int32 = 1879048210
MSG_Task_WebsiteVisit: Int32 = 1879048211
MSG_Task_Application: Int32 = 1879048212
MSG_Task_ComputerUsage: Int32 = 1879048213
MSG_Task_ContentUsage: Int32 = 1879048214
MSG_Publisher_Name: Int32 = -1879048191
MSG_Event_SettingChange: Int32 = -1342177279
MSG_Event_GameStart: Int32 = -1342177278
MSG_Event_UrlVisit: Int32 = -1342177277
MSG_Event_EmailReceived: Int32 = -1342177276
MSG_Event_EmailSent: Int32 = -1342177275
MSG_Event_MediaPlayback: Int32 = -1342177274
MSG_Event_IMInvitation: Int32 = -1342177273
MSG_Event_IMJoin: Int32 = -1342177272
MSG_Event_IMLeave: Int32 = -1342177271
MSG_Event_FileDownload: Int32 = -1342177270
MSG_Event_IMFeature: Int32 = -1342177269
MSG_Event_Custom: Int32 = -1342177267
MSG_Event_EmailContact: Int32 = -1342177266
MSG_Event_IMContact: Int32 = -1342177265
MSG_Event_AppBlocked: Int32 = -1342177264
MSG_Event_AppOverride: Int32 = -1342177263
MSG_Event_WebOverride: Int32 = -1342177262
MSG_Event_WebsiteVisit: Int32 = -1342177261
MSG_Event_Application: Int32 = -1342177260
MSG_Event_ComputerUsage: Int32 = -1342177259
MSG_Event_ContentUsage: Int32 = -1342177258
FACILITY_WPC: UInt32 = 2457
WPCPROV: Guid = Guid('{01090065-b467-4503-9b28-533766761087}')
class IWPCGamesSettings(ComPtr):
    extends: win32more.Windows.Win32.System.ParentalControls.IWPCSettings
    _iid_ = Guid('{95e87780-e158-489e-b452-bbb850790715}')
    @commethod(6)
    def IsBlocked(self, guidAppID: Guid, pdwReasons: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWPCProviderConfig(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bef54196-2d02-4a26-b6e5-d65af295d0f1}')
    @commethod(3)
    def GetUserSummary(self, bstrSID: win32more.Windows.Win32.Foundation.BSTR, pbstrUserSummary: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Configure(self, hWnd: win32more.Windows.Win32.Foundation.HWND, bstrSID: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RequestOverride(self, hWnd: win32more.Windows.Win32.Foundation.HWND, bstrPath: win32more.Windows.Win32.Foundation.BSTR, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWPCProviderState(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{50b6a267-c4bd-450b-adb5-759073837c9e}')
    @commethod(3)
    def Enable(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Disable(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWPCProviderSupport(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{41eba572-23ed-4779-bec1-8df96206c44c}')
    @commethod(3)
    def GetCurrent(self, pguidProvider: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWPCSettings(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8fdf6ca1-0189-47e4-b670-1a8a4636e340}')
    @commethod(3)
    def IsLoggingRequired(self, pfRequired: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetLastSettingsChangeTime(self, pTime: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetRestrictions(self, pdwRestrictions: POINTER(win32more.Windows.Win32.System.ParentalControls.WPCFLAG_RESTRICTION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWPCWebSettings(ComPtr):
    extends: win32more.Windows.Win32.System.ParentalControls.IWPCSettings
    _iid_ = Guid('{ffccbdb8-0992-4c30-b0f1-1cbb09c240aa}')
    @commethod(6)
    def GetSettings(self, pdwSettings: POINTER(win32more.Windows.Win32.System.ParentalControls.WPCFLAG_WEB_SETTING)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def RequestURLOverride(self, hWnd: win32more.Windows.Win32.Foundation.HWND, pcszURL: win32more.Windows.Win32.Foundation.PWSTR, cURLs: UInt32, ppcszSubURLs: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pfChanged: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWindowsParentalControls(ComPtr):
    extends: win32more.Windows.Win32.System.ParentalControls.IWindowsParentalControlsCore
    _iid_ = Guid('{28b4d88b-e072-49e6-804d-26edbe21a7b9}')
    @commethod(7)
    def GetGamesSettings(self, pcszSID: win32more.Windows.Win32.Foundation.PWSTR, ppSettings: POINTER(win32more.Windows.Win32.System.ParentalControls.IWPCGamesSettings)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWindowsParentalControlsCore(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4ff40a0f-3f3b-4d7c-a41b-4f39d7b44d05}')
    @commethod(3)
    def GetVisibility(self, peVisibility: POINTER(win32more.Windows.Win32.System.ParentalControls.WPCFLAG_VISIBILITY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetUserSettings(self, pcszSID: win32more.Windows.Win32.Foundation.PWSTR, ppSettings: POINTER(win32more.Windows.Win32.System.ParentalControls.IWPCSettings)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetWebSettings(self, pcszSID: win32more.Windows.Win32.Foundation.PWSTR, ppSettings: POINTER(win32more.Windows.Win32.System.ParentalControls.IWPCWebSettings)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetWebFilterInfo(self, pguidID: POINTER(Guid), ppszName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
WPCFLAG_IM_FEATURE = Int32
WPCFLAG_IM_FEATURE_NONE: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_FEATURE = 0
WPCFLAG_IM_FEATURE_VIDEO: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_FEATURE = 1
WPCFLAG_IM_FEATURE_AUDIO: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_FEATURE = 2
WPCFLAG_IM_FEATURE_GAME: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_FEATURE = 4
WPCFLAG_IM_FEATURE_SMS: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_FEATURE = 8
WPCFLAG_IM_FEATURE_FILESWAP: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_FEATURE = 16
WPCFLAG_IM_FEATURE_URLSWAP: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_FEATURE = 32
WPCFLAG_IM_FEATURE_SENDING: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_FEATURE = -2147483648
WPCFLAG_IM_FEATURE_ALL: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_FEATURE = -1
WPCFLAG_IM_LEAVE = Int32
WPCFLAG_IM_LEAVE_NORMAL: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_LEAVE = 0
WPCFLAG_IM_LEAVE_FORCED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_LEAVE = 1
WPCFLAG_IM_LEAVE_CONVERSATION_END: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_LEAVE = 2
WPCFLAG_ISBLOCKED = Int32
WPCFLAG_ISBLOCKED_NOTBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 0
WPCFLAG_ISBLOCKED_IMBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 1
WPCFLAG_ISBLOCKED_EMAILBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 2
WPCFLAG_ISBLOCKED_MEDIAPLAYBACKBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 4
WPCFLAG_ISBLOCKED_WEBBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 8
WPCFLAG_ISBLOCKED_GAMESBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 16
WPCFLAG_ISBLOCKED_CONTACTBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 32
WPCFLAG_ISBLOCKED_FEATUREBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 64
WPCFLAG_ISBLOCKED_DOWNLOADBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 128
WPCFLAG_ISBLOCKED_RATINGBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 256
WPCFLAG_ISBLOCKED_DESCRIPTORBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 512
WPCFLAG_ISBLOCKED_EXPLICITBLOCK: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 1024
WPCFLAG_ISBLOCKED_BADPASS: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 2048
WPCFLAG_ISBLOCKED_MAXHOURS: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 4096
WPCFLAG_ISBLOCKED_SPECHOURS: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 8192
WPCFLAG_ISBLOCKED_SETTINGSCHANGEBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 16384
WPCFLAG_ISBLOCKED_ATTACHMENTBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 32768
WPCFLAG_ISBLOCKED_SENDERBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 65536
WPCFLAG_ISBLOCKED_RECEIVERBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 131072
WPCFLAG_ISBLOCKED_NOTEXPLICITLYALLOWED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 262144
WPCFLAG_ISBLOCKED_NOTINLIST: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 524288
WPCFLAG_ISBLOCKED_CATEGORYBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 1048576
WPCFLAG_ISBLOCKED_CATEGORYNOTINLIST: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 2097152
WPCFLAG_ISBLOCKED_NOTKIDS: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 4194304
WPCFLAG_ISBLOCKED_UNRATED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 8388608
WPCFLAG_ISBLOCKED_NOACCESS: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 16777216
WPCFLAG_ISBLOCKED_INTERNALERROR: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = -1
WPCFLAG_LOGOFF_TYPE = Int32
WPCFLAG_LOGOFF_TYPE_LOGOUT: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_LOGOFF_TYPE = 0
WPCFLAG_LOGOFF_TYPE_RESTART: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_LOGOFF_TYPE = 1
WPCFLAG_LOGOFF_TYPE_SHUTDOWN: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_LOGOFF_TYPE = 2
WPCFLAG_LOGOFF_TYPE_FUS: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_LOGOFF_TYPE = 4
WPCFLAG_LOGOFF_TYPE_FORCEDFUS: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_LOGOFF_TYPE = 8
WPCFLAG_OVERRIDE = Int32
WPCFLAG_APPLICATION: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_OVERRIDE = 1
WPCFLAG_RESTRICTION = Int32
WPCFLAG_NO_RESTRICTION: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_RESTRICTION = 0
WPCFLAG_LOGGING_REQUIRED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_RESTRICTION = 1
WPCFLAG_WEB_FILTERED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_RESTRICTION = 2
WPCFLAG_HOURS_RESTRICTED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_RESTRICTION = 4
WPCFLAG_GAMES_BLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_RESTRICTION = 8
WPCFLAG_APPS_RESTRICTED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_RESTRICTION = 16
WPCFLAG_TIME_ALLOWANCE_RESTRICTED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_RESTRICTION = 32
WPCFLAG_GAMES_RESTRICTED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_RESTRICTION = 64
WPCFLAG_VISIBILITY = Int32
WPCFLAG_WPC_VISIBLE: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_VISIBILITY = 0
WPCFLAG_WPC_HIDDEN: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_VISIBILITY = 1
WPCFLAG_WEB_SETTING = Int32
WPCFLAG_WEB_SETTING_NOTBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_WEB_SETTING = 0
WPCFLAG_WEB_SETTING_DOWNLOADSBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_WEB_SETTING = 1
WPC_ARGS_APPLICATIONEVENT = Int32
WPC_ARGS_APPLICATIONEVENT_SERIALIZEDAPPLICATION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPLICATIONEVENT = 0
WPC_ARGS_APPLICATIONEVENT_DECISION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPLICATIONEVENT = 1
WPC_ARGS_APPLICATIONEVENT_PROCESSID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPLICATIONEVENT = 2
WPC_ARGS_APPLICATIONEVENT_CREATIONTIME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPLICATIONEVENT = 3
WPC_ARGS_APPLICATIONEVENT_TIMEUSED: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPLICATIONEVENT = 4
WPC_ARGS_APPLICATIONEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPLICATIONEVENT = 5
WPC_ARGS_APPOVERRIDEEVENT = Int32
WPC_ARGS_APPOVERRIDEEVENT_USERID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPOVERRIDEEVENT = 0
WPC_ARGS_APPOVERRIDEEVENT_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPOVERRIDEEVENT = 1
WPC_ARGS_APPOVERRIDEEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPOVERRIDEEVENT = 2
WPC_ARGS_APPOVERRIDEEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPOVERRIDEEVENT = 3
WPC_ARGS_COMPUTERUSAGEEVENT = Int32
WPC_ARGS_COMPUTERUSAGEEVENT_ID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_COMPUTERUSAGEEVENT = 0
WPC_ARGS_COMPUTERUSAGEEVENT_TIMEUSED: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_COMPUTERUSAGEEVENT = 1
WPC_ARGS_COMPUTERUSAGEEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_COMPUTERUSAGEEVENT = 2
WPC_ARGS_CONTENTUSAGEEVENT = Int32
WPC_ARGS_CONTENTUSAGEEVENT_CONTENTPROVIDERID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONTENTUSAGEEVENT = 0
WPC_ARGS_CONTENTUSAGEEVENT_CONTENTPROVIDERTITLE: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONTENTUSAGEEVENT = 1
WPC_ARGS_CONTENTUSAGEEVENT_ID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONTENTUSAGEEVENT = 2
WPC_ARGS_CONTENTUSAGEEVENT_TITLE: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONTENTUSAGEEVENT = 3
WPC_ARGS_CONTENTUSAGEEVENT_CATEGORY: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONTENTUSAGEEVENT = 4
WPC_ARGS_CONTENTUSAGEEVENT_RATINGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONTENTUSAGEEVENT = 5
WPC_ARGS_CONTENTUSAGEEVENT_DECISION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONTENTUSAGEEVENT = 6
WPC_ARGS_CONTENTUSAGEEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONTENTUSAGEEVENT = 7
WPC_ARGS_CONVERSATIONINITEVENT = Int32
WPC_ARGS_CONVERSATIONINITEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 0
WPC_ARGS_CONVERSATIONINITEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 1
WPC_ARGS_CONVERSATIONINITEVENT_ACCOUNTNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 2
WPC_ARGS_CONVERSATIONINITEVENT_CONVID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 3
WPC_ARGS_CONVERSATIONINITEVENT_REQUESTINGIP: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 4
WPC_ARGS_CONVERSATIONINITEVENT_SENDER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 5
WPC_ARGS_CONVERSATIONINITEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 6
WPC_ARGS_CONVERSATIONINITEVENT_RECIPCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 7
WPC_ARGS_CONVERSATIONINITEVENT_RECIPIENT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 8
WPC_ARGS_CONVERSATIONINITEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 9
WPC_ARGS_CONVERSATIONJOINEVENT = Int32
WPC_ARGS_CONVERSATIONJOINEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 0
WPC_ARGS_CONVERSATIONJOINEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 1
WPC_ARGS_CONVERSATIONJOINEVENT_ACCOUNTNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 2
WPC_ARGS_CONVERSATIONJOINEVENT_CONVID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 3
WPC_ARGS_CONVERSATIONJOINEVENT_JOININGIP: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 4
WPC_ARGS_CONVERSATIONJOINEVENT_JOININGUSER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 5
WPC_ARGS_CONVERSATIONJOINEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 6
WPC_ARGS_CONVERSATIONJOINEVENT_MEMBERCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 7
WPC_ARGS_CONVERSATIONJOINEVENT_MEMBER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 8
WPC_ARGS_CONVERSATIONJOINEVENT_SENDER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 9
WPC_ARGS_CONVERSATIONJOINEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 10
WPC_ARGS_CONVERSATIONLEAVEEVENT = Int32
WPC_ARGS_CONVERSATIONLEAVEEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 0
WPC_ARGS_CONVERSATIONLEAVEEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 1
WPC_ARGS_CONVERSATIONLEAVEEVENT_ACCOUNTNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 2
WPC_ARGS_CONVERSATIONLEAVEEVENT_CONVID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 3
WPC_ARGS_CONVERSATIONLEAVEEVENT_LEAVINGIP: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 4
WPC_ARGS_CONVERSATIONLEAVEEVENT_LEAVINGUSER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 5
WPC_ARGS_CONVERSATIONLEAVEEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 6
WPC_ARGS_CONVERSATIONLEAVEEVENT_MEMBERCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 7
WPC_ARGS_CONVERSATIONLEAVEEVENT_MEMBER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 8
WPC_ARGS_CONVERSATIONLEAVEEVENT_FLAGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 9
WPC_ARGS_CONVERSATIONLEAVEEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 10
WPC_ARGS_CUSTOMEVENT = Int32
WPC_ARGS_CUSTOMEVENT_PUBLISHER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 0
WPC_ARGS_CUSTOMEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 1
WPC_ARGS_CUSTOMEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 2
WPC_ARGS_CUSTOMEVENT_EVENT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 3
WPC_ARGS_CUSTOMEVENT_VALUE1: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 4
WPC_ARGS_CUSTOMEVENT_VALUE2: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 5
WPC_ARGS_CUSTOMEVENT_VALUE3: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 6
WPC_ARGS_CUSTOMEVENT_BLOCKED: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 7
WPC_ARGS_CUSTOMEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 8
WPC_ARGS_CUSTOMEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 9
WPC_ARGS_EMAILCONTACTEVENT = Int32
WPC_ARGS_EMAILCONTACTEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILCONTACTEVENT = 0
WPC_ARGS_EMAILCONTACTEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILCONTACTEVENT = 1
WPC_ARGS_EMAILCONTACTEVENT_OLDNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILCONTACTEVENT = 2
WPC_ARGS_EMAILCONTACTEVENT_OLDID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILCONTACTEVENT = 3
WPC_ARGS_EMAILCONTACTEVENT_NEWNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILCONTACTEVENT = 4
WPC_ARGS_EMAILCONTACTEVENT_NEWID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILCONTACTEVENT = 5
WPC_ARGS_EMAILCONTACTEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILCONTACTEVENT = 6
WPC_ARGS_EMAILCONTACTEVENT_EMAILACCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILCONTACTEVENT = 7
WPC_ARGS_EMAILCONTACTEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILCONTACTEVENT = 8
WPC_ARGS_EMAILRECEIEVEDEVENT = Int32
WPC_ARGS_EMAILRECEIEVEDEVENT_SENDER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 0
WPC_ARGS_EMAILRECEIEVEDEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 1
WPC_ARGS_EMAILRECEIEVEDEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 2
WPC_ARGS_EMAILRECEIEVEDEVENT_SUBJECT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 3
WPC_ARGS_EMAILRECEIEVEDEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 4
WPC_ARGS_EMAILRECEIEVEDEVENT_RECIPCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 5
WPC_ARGS_EMAILRECEIEVEDEVENT_RECIPIENT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 6
WPC_ARGS_EMAILRECEIEVEDEVENT_ATTACHCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 7
WPC_ARGS_EMAILRECEIEVEDEVENT_ATTACHMENTNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 8
WPC_ARGS_EMAILRECEIEVEDEVENT_RECEIVEDTIME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 9
WPC_ARGS_EMAILRECEIEVEDEVENT_EMAILACCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 10
WPC_ARGS_EMAILRECEIEVEDEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 11
WPC_ARGS_EMAILSENTEVENT = Int32
WPC_ARGS_EMAILSENTEVENT_SENDER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 0
WPC_ARGS_EMAILSENTEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 1
WPC_ARGS_EMAILSENTEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 2
WPC_ARGS_EMAILSENTEVENT_SUBJECT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 3
WPC_ARGS_EMAILSENTEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 4
WPC_ARGS_EMAILSENTEVENT_RECIPCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 5
WPC_ARGS_EMAILSENTEVENT_RECIPIENT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 6
WPC_ARGS_EMAILSENTEVENT_ATTACHCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 7
WPC_ARGS_EMAILSENTEVENT_ATTACHMENTNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 8
WPC_ARGS_EMAILSENTEVENT_EMAILACCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 9
WPC_ARGS_EMAILSENTEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 10
WPC_ARGS_FILEDOWNLOADEVENT = Int32
WPC_ARGS_FILEDOWNLOADEVENT_URL: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_FILEDOWNLOADEVENT = 0
WPC_ARGS_FILEDOWNLOADEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_FILEDOWNLOADEVENT = 1
WPC_ARGS_FILEDOWNLOADEVENT_VERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_FILEDOWNLOADEVENT = 2
WPC_ARGS_FILEDOWNLOADEVENT_BLOCKED: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_FILEDOWNLOADEVENT = 3
WPC_ARGS_FILEDOWNLOADEVENT_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_FILEDOWNLOADEVENT = 4
WPC_ARGS_FILEDOWNLOADEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_FILEDOWNLOADEVENT = 5
WPC_ARGS_GAMESTARTEVENT = Int32
WPC_ARGS_GAMESTARTEVENT_APPID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 0
WPC_ARGS_GAMESTARTEVENT_INSTANCEID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 1
WPC_ARGS_GAMESTARTEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 2
WPC_ARGS_GAMESTARTEVENT_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 3
WPC_ARGS_GAMESTARTEVENT_RATING: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 4
WPC_ARGS_GAMESTARTEVENT_RATINGSYSTEM: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 5
WPC_ARGS_GAMESTARTEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 6
WPC_ARGS_GAMESTARTEVENT_DESCCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 7
WPC_ARGS_GAMESTARTEVENT_DESCRIPTOR: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 8
WPC_ARGS_GAMESTARTEVENT_PID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 9
WPC_ARGS_GAMESTARTEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 10
WPC_ARGS_IMCONTACTEVENT = Int32
WPC_ARGS_IMCONTACTEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMCONTACTEVENT = 0
WPC_ARGS_IMCONTACTEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMCONTACTEVENT = 1
WPC_ARGS_IMCONTACTEVENT_ACCOUNTNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMCONTACTEVENT = 2
WPC_ARGS_IMCONTACTEVENT_OLDNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMCONTACTEVENT = 3
WPC_ARGS_IMCONTACTEVENT_OLDID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMCONTACTEVENT = 4
WPC_ARGS_IMCONTACTEVENT_NEWNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMCONTACTEVENT = 5
WPC_ARGS_IMCONTACTEVENT_NEWID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMCONTACTEVENT = 6
WPC_ARGS_IMCONTACTEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMCONTACTEVENT = 7
WPC_ARGS_IMCONTACTEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMCONTACTEVENT = 8
WPC_ARGS_IMFEATUREEVENT = Int32
WPC_ARGS_IMFEATUREEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 0
WPC_ARGS_IMFEATUREEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 1
WPC_ARGS_IMFEATUREEVENT_ACCOUNTNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 2
WPC_ARGS_IMFEATUREEVENT_CONVID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 3
WPC_ARGS_IMFEATUREEVENT_MEDIATYPE: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 4
WPC_ARGS_IMFEATUREEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 5
WPC_ARGS_IMFEATUREEVENT_RECIPCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 6
WPC_ARGS_IMFEATUREEVENT_RECIPIENT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 7
WPC_ARGS_IMFEATUREEVENT_SENDER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 8
WPC_ARGS_IMFEATUREEVENT_SENDERIP: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 9
WPC_ARGS_IMFEATUREEVENT_DATA: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 10
WPC_ARGS_IMFEATUREEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 11
WPC_ARGS_MEDIADOWNLOADEVENT = Int32
WPC_ARGS_MEDIADOWNLOADEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 0
WPC_ARGS_MEDIADOWNLOADEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 1
WPC_ARGS_MEDIADOWNLOADEVENT_MEDIATYPE: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 2
WPC_ARGS_MEDIADOWNLOADEVENT_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 3
WPC_ARGS_MEDIADOWNLOADEVENT_TITLE: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 4
WPC_ARGS_MEDIADOWNLOADEVENT_PML: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 5
WPC_ARGS_MEDIADOWNLOADEVENT_ALBUM: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 6
WPC_ARGS_MEDIADOWNLOADEVENT_EXPLICIT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 7
WPC_ARGS_MEDIADOWNLOADEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 8
WPC_ARGS_MEDIADOWNLOADEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 9
WPC_ARGS_MEDIAPLAYBACKEVENT = Int32
WPC_ARGS_MEDIAPLAYBACKEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 0
WPC_ARGS_MEDIAPLAYBACKEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 1
WPC_ARGS_MEDIAPLAYBACKEVENT_MEDIATYPE: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 2
WPC_ARGS_MEDIAPLAYBACKEVENT_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 3
WPC_ARGS_MEDIAPLAYBACKEVENT_TITLE: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 4
WPC_ARGS_MEDIAPLAYBACKEVENT_PML: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 5
WPC_ARGS_MEDIAPLAYBACKEVENT_ALBUM: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 6
WPC_ARGS_MEDIAPLAYBACKEVENT_EXPLICIT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 7
WPC_ARGS_MEDIAPLAYBACKEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 8
WPC_ARGS_MEDIAPLAYBACKEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 9
WPC_ARGS_SAFERAPPBLOCKED = Int32
WPC_ARGS_SAFERAPPBLOCKED_TIMESTAMP: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SAFERAPPBLOCKED = 0
WPC_ARGS_SAFERAPPBLOCKED_USERID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SAFERAPPBLOCKED = 1
WPC_ARGS_SAFERAPPBLOCKED_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SAFERAPPBLOCKED = 2
WPC_ARGS_SAFERAPPBLOCKED_RULEID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SAFERAPPBLOCKED = 3
WPC_ARGS_SAFERAPPBLOCKED_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SAFERAPPBLOCKED = 4
WPC_ARGS_SETTINGSCHANGEEVENT = Int32
WPC_ARGS_SETTINGSCHANGEEVENT_CLASS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SETTINGSCHANGEEVENT = 0
WPC_ARGS_SETTINGSCHANGEEVENT_SETTING: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SETTINGSCHANGEEVENT = 1
WPC_ARGS_SETTINGSCHANGEEVENT_OWNER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SETTINGSCHANGEEVENT = 2
WPC_ARGS_SETTINGSCHANGEEVENT_OLDVAL: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SETTINGSCHANGEEVENT = 3
WPC_ARGS_SETTINGSCHANGEEVENT_NEWVAL: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SETTINGSCHANGEEVENT = 4
WPC_ARGS_SETTINGSCHANGEEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SETTINGSCHANGEEVENT = 5
WPC_ARGS_SETTINGSCHANGEEVENT_OPTIONAL: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SETTINGSCHANGEEVENT = 6
WPC_ARGS_SETTINGSCHANGEEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SETTINGSCHANGEEVENT = 7
WPC_ARGS_URLVISITEVENT = Int32
WPC_ARGS_URLVISITEVENT_URL: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_URLVISITEVENT = 0
WPC_ARGS_URLVISITEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_URLVISITEVENT = 1
WPC_ARGS_URLVISITEVENT_VERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_URLVISITEVENT = 2
WPC_ARGS_URLVISITEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_URLVISITEVENT = 3
WPC_ARGS_URLVISITEVENT_RATINGSYSTEMID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_URLVISITEVENT = 4
WPC_ARGS_URLVISITEVENT_CATCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_URLVISITEVENT = 5
WPC_ARGS_URLVISITEVENT_CATEGORY: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_URLVISITEVENT = 6
WPC_ARGS_URLVISITEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_URLVISITEVENT = 7
WPC_ARGS_WEBOVERRIDEEVENT = Int32
WPC_ARGS_WEBOVERRIDEEVENT_USERID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBOVERRIDEEVENT = 0
WPC_ARGS_WEBOVERRIDEEVENT_URL: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBOVERRIDEEVENT = 1
WPC_ARGS_WEBOVERRIDEEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBOVERRIDEEVENT = 2
WPC_ARGS_WEBOVERRIDEEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBOVERRIDEEVENT = 3
WPC_ARGS_WEBSITEVISITEVENT = Int32
WPC_ARGS_WEBSITEVISITEVENT_URL: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 0
WPC_ARGS_WEBSITEVISITEVENT_DECISION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 1
WPC_ARGS_WEBSITEVISITEVENT_CATEGORIES: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 2
WPC_ARGS_WEBSITEVISITEVENT_BLOCKEDCATEGORIES: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 3
WPC_ARGS_WEBSITEVISITEVENT_SERIALIZEDAPPLICATION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 4
WPC_ARGS_WEBSITEVISITEVENT_TITLE: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 5
WPC_ARGS_WEBSITEVISITEVENT_CONTENTTYPE: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 6
WPC_ARGS_WEBSITEVISITEVENT_REFERRER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 7
WPC_ARGS_WEBSITEVISITEVENT_TELEMETRY: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 8
WPC_ARGS_WEBSITEVISITEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 9
WPC_MEDIA_EXPLICIT = Int32
WPC_MEDIA_EXPLICIT_FALSE: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_EXPLICIT = 0
WPC_MEDIA_EXPLICIT_TRUE: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_EXPLICIT = 1
WPC_MEDIA_EXPLICIT_UNKNOWN: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_EXPLICIT = 2
WPC_MEDIA_TYPE = Int32
WPC_MEDIA_TYPE_OTHER: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_TYPE = 0
WPC_MEDIA_TYPE_DVD: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_TYPE = 1
WPC_MEDIA_TYPE_RECORDED_TV: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_TYPE = 2
WPC_MEDIA_TYPE_AUDIO_FILE: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_TYPE = 3
WPC_MEDIA_TYPE_CD_AUDIO: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_TYPE = 4
WPC_MEDIA_TYPE_VIDEO_FILE: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_TYPE = 5
WPC_MEDIA_TYPE_PICTURE_FILE: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_TYPE = 6
WPC_MEDIA_TYPE_MAX: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_TYPE = 7
WPC_SETTINGS = Int32
WPC_SETTINGS_WPC_EXTENSION_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 0
WPC_SETTINGS_WPC_EXTENSION_SILO: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 1
WPC_SETTINGS_WPC_EXTENSION_IMAGE_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 2
WPC_SETTINGS_WPC_EXTENSION_DISABLEDIMAGE_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 3
WPC_SETTINGS_WPC_EXTENSION_NAME: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 4
WPC_SETTINGS_WPC_EXTENSION_SUB_TITLE: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 5
WPC_SETTINGS_SYSTEM_CURRENT_RATING_SYSTEM: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 6
WPC_SETTINGS_SYSTEM_LAST_LOG_VIEW: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 7
WPC_SETTINGS_SYSTEM_LOG_VIEW_REMINDER_INTERVAL: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 8
WPC_SETTINGS_SYSTEM_HTTP_EXEMPTION_LIST: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 9
WPC_SETTINGS_SYSTEM_URL_EXEMPTION_LIST: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 10
WPC_SETTINGS_SYSTEM_FILTER_ID: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 11
WPC_SETTINGS_SYSTEM_FILTER_NAME: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 12
WPC_SETTINGS_SYSTEM_LOCALE: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 13
WPC_SETTINGS_ALLOW_BLOCK: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 14
WPC_SETTINGS_GAME_BLOCKED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 15
WPC_SETTINGS_GAME_ALLOW_UNRATED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 16
WPC_SETTINGS_GAME_MAX_ALLOWED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 17
WPC_SETTINGS_GAME_DENIED_DESCRIPTORS: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 18
WPC_SETTINGS_USER_WPC_ENABLED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 19
WPC_SETTINGS_USER_LOGGING_REQUIRED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 20
WPC_SETTINGS_USER_HOURLY_RESTRICTIONS: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 21
WPC_SETTINGS_USER_OVERRRIDE_REQUESTS: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 22
WPC_SETTINGS_USER_LOGON_HOURS: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 23
WPC_SETTINGS_USER_APP_RESTRICTIONS: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 24
WPC_SETTINGS_WEB_FILTER_ON: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 25
WPC_SETTINGS_WEB_DOWNLOAD_BLOCKED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 26
WPC_SETTINGS_WEB_FILTER_LEVEL: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 27
WPC_SETTINGS_WEB_BLOCKED_CATEGORY_LIST: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 28
WPC_SETTINGS_WEB_BLOCK_UNRATED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 29
WPC_SETTINGS_WPC_ENABLED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 30
WPC_SETTINGS_WPC_LOGGING_REQUIRED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 31
WPC_SETTINGS_RATING_SYSTEM_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 32
WPC_SETTINGS_WPC_PROVIDER_CURRENT: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 33
WPC_SETTINGS_USER_TIME_ALLOWANCE: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 34
WPC_SETTINGS_USER_TIME_ALLOWANCE_RESTRICTIONS: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 35
WPC_SETTINGS_GAME_RESTRICTED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 36
WPC_SETTING_COUNT: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 37
WindowsParentalControls = Guid('{e77cc89b-7401-4c04-8ced-149db35add04}')
WpcProviderSupport = Guid('{bb18c7a0-2186-4be0-97d8-04847b628e02}')
WpcSettingsProvider = Guid('{355dffaa-3b9f-435c-b428-5d44290bc5f2}')


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
import win32more.Windows.Win32.System.WinRT.Composition
import win32more.Windows.Win32.UI.Input.Pointer
class ICompositionCapabilitiesInteropFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _iid_ = Guid('{2c9db356-e70d-4642-8298-bc4aa5b4865c}')
    @commethod(6)
    def GetForWindow(self, hwnd: win32more.Windows.Win32.Foundation.HWND, result: POINTER(win32more.Windows.UI.Composition.CompositionCapabilities)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICompositionDrawingSurfaceInterop(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{fd04e6e3-fe0c-4c3c-ab19-a07601a576ee}')
    @commethod(3)
    def BeginDraw(self, updateRect: POINTER(win32more.Windows.Win32.Foundation.RECT), iid: POINTER(Guid), updateObject: POINTER(VoidPtr), updateOffset: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EndDraw(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Resize(self, sizePixels: win32more.Windows.Win32.Foundation.SIZE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Scroll(self, scrollRect: POINTER(win32more.Windows.Win32.Foundation.RECT), clipRect: POINTER(win32more.Windows.Win32.Foundation.RECT), offsetX: Int32, offsetY: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ResumeDraw(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SuspendDraw(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICompositionDrawingSurfaceInterop2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.Composition.ICompositionDrawingSurfaceInterop
    _iid_ = Guid('{41e64aae-98c0-4239-8e95-a330dd6aa18b}')
    @commethod(9)
    def CopySurface(self, destinationResource: win32more.Windows.Win32.System.Com.IUnknown, destinationOffsetX: Int32, destinationOffsetY: Int32, sourceRectangle: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICompositionGraphicsDeviceInterop(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a116ff71-f8bf-4c8a-9c98-70779a32a9c8}')
    @commethod(3)
    def GetRenderingDevice(self, value: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetRenderingDevice(self, value: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICompositionTextureInterop(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d528a265-f0a5-422f-a39d-ef62d7cd1cc4}')
    @commethod(3)
    def GetAvailableFence(self, fenceValue: POINTER(UInt64), iid: POINTER(Guid), availableFence: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICompositorDesktopInterop(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{29e691fa-4567-4dca-b319-d0f207eb6807}')
    @commethod(3)
    def CreateDesktopWindowTarget(self, hwndTarget: win32more.Windows.Win32.Foundation.HWND, isTopmost: win32more.Windows.Win32.Foundation.BOOL, result: POINTER(win32more.Windows.UI.Composition.Desktop.DesktopWindowTarget)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EnsureOnThread(self, threadId: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICompositorInterop(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{25297d5c-3ad4-4c9c-b5cf-e36a38512330}')
    @commethod(3)
    def CreateCompositionSurfaceForHandle(self, swapChain: win32more.Windows.Win32.Foundation.HANDLE, result: POINTER(win32more.Windows.UI.Composition.ICompositionSurface)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateCompositionSurfaceForSwapChain(self, swapChain: win32more.Windows.Win32.System.Com.IUnknown, result: POINTER(win32more.Windows.UI.Composition.ICompositionSurface)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateGraphicsDevice(self, renderingDevice: win32more.Windows.Win32.System.Com.IUnknown, result: POINTER(win32more.Windows.UI.Composition.CompositionGraphicsDevice)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICompositorInterop2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d3eef34c-0667-4afc-8d13-867607b0fe91}')
    @commethod(3)
    def CheckCompositionTextureSupport(self, renderingDevice: win32more.Windows.Win32.System.Com.IUnknown, supportsCompositionTextures: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateCompositionTexture(self, d3dTexture: win32more.Windows.Win32.System.Com.IUnknown, compositionTexture: POINTER(win32more.Windows.UI.Composition.CompositionTexture)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDesktopWindowTargetInterop(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{35dbf59e-e3f9-45b0-81e7-fe75f4145dc9}')
    @commethod(3)
    def get_Hwnd(self, value: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVisualInteractionSourceInterop(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{11f62cd1-2f9d-42d3-b05f-d6790d9e9f8e}')
    @commethod(3)
    def TryRedirectForManipulation(self, pointerInfo: POINTER(win32more.Windows.Win32.UI.Input.Pointer.POINTER_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Data.Json
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.System
import win32more.Windows.System.Diagnostics
import win32more.Windows.Win32.System.WinRT
class DiagnosticActionResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Diagnostics.IDiagnosticActionResult
    _classid_ = 'Windows.System.Diagnostics.DiagnosticActionResult'
    @winrt_mixinmethod
    def get_ExtendedError(self: win32more.Windows.System.Diagnostics.IDiagnosticActionResult) -> win32more.Windows.Foundation.HResult: ...
    @winrt_mixinmethod
    def get_Results(self: win32more.Windows.System.Diagnostics.IDiagnosticActionResult) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    ExtendedError = property(get_ExtendedError, None)
    Results = property(get_Results, None)
class DiagnosticActionState(Enum, Int32):
    Initializing = 0
    Downloading = 1
    VerifyingTrust = 2
    Detecting = 3
    Resolving = 4
    VerifyingResolution = 5
    Executing = 6
class _DiagnosticInvoker_Meta_(ComPtr.__class__):
    pass
class DiagnosticInvoker(ComPtr, metaclass=_DiagnosticInvoker_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Diagnostics.IDiagnosticInvoker
    _classid_ = 'Windows.System.Diagnostics.DiagnosticInvoker'
    @winrt_mixinmethod
    def RunDiagnosticActionAsync(self: win32more.Windows.System.Diagnostics.IDiagnosticInvoker, context: win32more.Windows.Data.Json.JsonObject) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.System.Diagnostics.DiagnosticActionResult, win32more.Windows.System.Diagnostics.DiagnosticActionState]: ...
    @winrt_mixinmethod
    def RunDiagnosticActionFromStringAsync(self: win32more.Windows.System.Diagnostics.IDiagnosticInvoker2, context: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.System.Diagnostics.DiagnosticActionResult, win32more.Windows.System.Diagnostics.DiagnosticActionState]: ...
    @winrt_classmethod
    def GetDefault(cls: win32more.Windows.System.Diagnostics.IDiagnosticInvokerStatics) -> win32more.Windows.System.Diagnostics.DiagnosticInvoker: ...
    @winrt_classmethod
    def GetForUser(cls: win32more.Windows.System.Diagnostics.IDiagnosticInvokerStatics, user: win32more.Windows.System.User) -> win32more.Windows.System.Diagnostics.DiagnosticInvoker: ...
    @winrt_classmethod
    def get_IsSupported(cls: win32more.Windows.System.Diagnostics.IDiagnosticInvokerStatics) -> Boolean: ...
    _DiagnosticInvoker_Meta_.IsSupported = property(get_IsSupported, None)
class IDiagnosticActionResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.IDiagnosticActionResult'
    _iid_ = Guid('{c265a296-e73b-4097-b28f-3442f03dd831}')
    @winrt_commethod(6)
    def get_ExtendedError(self) -> win32more.Windows.Foundation.HResult: ...
    @winrt_commethod(7)
    def get_Results(self) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    ExtendedError = property(get_ExtendedError, None)
    Results = property(get_Results, None)
class IDiagnosticInvoker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.IDiagnosticInvoker'
    _iid_ = Guid('{187b270a-02e3-4f86-84fc-fdd892b5940f}')
    @winrt_commethod(6)
    def RunDiagnosticActionAsync(self, context: win32more.Windows.Data.Json.JsonObject) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.System.Diagnostics.DiagnosticActionResult, win32more.Windows.System.Diagnostics.DiagnosticActionState]: ...
class IDiagnosticInvoker2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.IDiagnosticInvoker2'
    _iid_ = Guid('{e3bf945c-155a-4b52-a8ec-070c44f95000}')
    @winrt_commethod(6)
    def RunDiagnosticActionFromStringAsync(self, context: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.System.Diagnostics.DiagnosticActionResult, win32more.Windows.System.Diagnostics.DiagnosticActionState]: ...
class IDiagnosticInvokerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.IDiagnosticInvokerStatics'
    _iid_ = Guid('{5cfad8de-f15c-4554-a813-c113c3881b09}')
    @winrt_commethod(6)
    def GetDefault(self) -> win32more.Windows.System.Diagnostics.DiagnosticInvoker: ...
    @winrt_commethod(7)
    def GetForUser(self, user: win32more.Windows.System.User) -> win32more.Windows.System.Diagnostics.DiagnosticInvoker: ...
    @winrt_commethod(8)
    def get_IsSupported(self) -> Boolean: ...
    IsSupported = property(get_IsSupported, None)
class IProcessCpuUsage(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.IProcessCpuUsage'
    _iid_ = Guid('{0bbb2472-c8bf-423a-a810-b559ae4354e2}')
    @winrt_commethod(6)
    def GetReport(self) -> win32more.Windows.System.Diagnostics.ProcessCpuUsageReport: ...
class IProcessCpuUsageReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.IProcessCpuUsageReport'
    _iid_ = Guid('{8a6d9cac-3987-4e2f-a119-6b5fa214f1b4}')
    @winrt_commethod(6)
    def get_KernelTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(7)
    def get_UserTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    KernelTime = property(get_KernelTime, None)
    UserTime = property(get_UserTime, None)
class IProcessDiagnosticInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.IProcessDiagnosticInfo'
    _iid_ = Guid('{e830b04b-300e-4ee6-a0ab-5b5f5231b434}')
    @winrt_commethod(6)
    def get_ProcessId(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_ExecutableFileName(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_Parent(self) -> win32more.Windows.System.Diagnostics.ProcessDiagnosticInfo: ...
    @winrt_commethod(9)
    def get_ProcessStartTime(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(10)
    def get_DiskUsage(self) -> win32more.Windows.System.Diagnostics.ProcessDiskUsage: ...
    @winrt_commethod(11)
    def get_MemoryUsage(self) -> win32more.Windows.System.Diagnostics.ProcessMemoryUsage: ...
    @winrt_commethod(12)
    def get_CpuUsage(self) -> win32more.Windows.System.Diagnostics.ProcessCpuUsage: ...
    CpuUsage = property(get_CpuUsage, None)
    DiskUsage = property(get_DiskUsage, None)
    ExecutableFileName = property(get_ExecutableFileName, None)
    MemoryUsage = property(get_MemoryUsage, None)
    Parent = property(get_Parent, None)
    ProcessId = property(get_ProcessId, None)
    ProcessStartTime = property(get_ProcessStartTime, None)
class IProcessDiagnosticInfo2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.IProcessDiagnosticInfo2'
    _iid_ = Guid('{9558cb1a-3d0b-49ec-ab70-4f7a112805de}')
    @winrt_commethod(6)
    def GetAppDiagnosticInfos(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.System.AppDiagnosticInfo]: ...
    @winrt_commethod(7)
    def get_IsPackaged(self) -> Boolean: ...
    IsPackaged = property(get_IsPackaged, None)
class IProcessDiagnosticInfoStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.IProcessDiagnosticInfoStatics'
    _iid_ = Guid('{2f41b260-b49f-428c-aa0e-84744f49ca95}')
    @winrt_commethod(6)
    def GetForProcesses(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.System.Diagnostics.ProcessDiagnosticInfo]: ...
    @winrt_commethod(7)
    def GetForCurrentProcess(self) -> win32more.Windows.System.Diagnostics.ProcessDiagnosticInfo: ...
class IProcessDiagnosticInfoStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.IProcessDiagnosticInfoStatics2'
    _iid_ = Guid('{4a869897-9899-4a44-a29b-091663be09b6}')
    @winrt_commethod(6)
    def TryGetForProcessId(self, processId: UInt32) -> win32more.Windows.System.Diagnostics.ProcessDiagnosticInfo: ...
class IProcessDiskUsage(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.IProcessDiskUsage'
    _iid_ = Guid('{5ad78bfd-7e51-4e53-bfaa-5a6ee1aabbf8}')
    @winrt_commethod(6)
    def GetReport(self) -> win32more.Windows.System.Diagnostics.ProcessDiskUsageReport: ...
class IProcessDiskUsageReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.IProcessDiskUsageReport'
    _iid_ = Guid('{401627fd-535d-4c1f-81b8-da54e1be635e}')
    @winrt_commethod(6)
    def get_ReadOperationCount(self) -> Int64: ...
    @winrt_commethod(7)
    def get_WriteOperationCount(self) -> Int64: ...
    @winrt_commethod(8)
    def get_OtherOperationCount(self) -> Int64: ...
    @winrt_commethod(9)
    def get_BytesReadCount(self) -> Int64: ...
    @winrt_commethod(10)
    def get_BytesWrittenCount(self) -> Int64: ...
    @winrt_commethod(11)
    def get_OtherBytesCount(self) -> Int64: ...
    BytesReadCount = property(get_BytesReadCount, None)
    BytesWrittenCount = property(get_BytesWrittenCount, None)
    OtherBytesCount = property(get_OtherBytesCount, None)
    OtherOperationCount = property(get_OtherOperationCount, None)
    ReadOperationCount = property(get_ReadOperationCount, None)
    WriteOperationCount = property(get_WriteOperationCount, None)
class IProcessMemoryUsage(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.IProcessMemoryUsage'
    _iid_ = Guid('{f50b229b-827c-42b7-b07c-0e32627e6b3e}')
    @winrt_commethod(6)
    def GetReport(self) -> win32more.Windows.System.Diagnostics.ProcessMemoryUsageReport: ...
class IProcessMemoryUsageReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.IProcessMemoryUsageReport'
    _iid_ = Guid('{c2c77cba-1951-4685-8532-7e749ecf8eeb}')
    @winrt_commethod(6)
    def get_NonPagedPoolSizeInBytes(self) -> UInt64: ...
    @winrt_commethod(7)
    def get_PageFaultCount(self) -> UInt32: ...
    @winrt_commethod(8)
    def get_PageFileSizeInBytes(self) -> UInt64: ...
    @winrt_commethod(9)
    def get_PagedPoolSizeInBytes(self) -> UInt64: ...
    @winrt_commethod(10)
    def get_PeakNonPagedPoolSizeInBytes(self) -> UInt64: ...
    @winrt_commethod(11)
    def get_PeakPageFileSizeInBytes(self) -> UInt64: ...
    @winrt_commethod(12)
    def get_PeakPagedPoolSizeInBytes(self) -> UInt64: ...
    @winrt_commethod(13)
    def get_PeakVirtualMemorySizeInBytes(self) -> UInt64: ...
    @winrt_commethod(14)
    def get_PeakWorkingSetSizeInBytes(self) -> UInt64: ...
    @winrt_commethod(15)
    def get_PrivatePageCount(self) -> UInt64: ...
    @winrt_commethod(16)
    def get_VirtualMemorySizeInBytes(self) -> UInt64: ...
    @winrt_commethod(17)
    def get_WorkingSetSizeInBytes(self) -> UInt64: ...
    NonPagedPoolSizeInBytes = property(get_NonPagedPoolSizeInBytes, None)
    PageFaultCount = property(get_PageFaultCount, None)
    PageFileSizeInBytes = property(get_PageFileSizeInBytes, None)
    PagedPoolSizeInBytes = property(get_PagedPoolSizeInBytes, None)
    PeakNonPagedPoolSizeInBytes = property(get_PeakNonPagedPoolSizeInBytes, None)
    PeakPageFileSizeInBytes = property(get_PeakPageFileSizeInBytes, None)
    PeakPagedPoolSizeInBytes = property(get_PeakPagedPoolSizeInBytes, None)
    PeakVirtualMemorySizeInBytes = property(get_PeakVirtualMemorySizeInBytes, None)
    PeakWorkingSetSizeInBytes = property(get_PeakWorkingSetSizeInBytes, None)
    PrivatePageCount = property(get_PrivatePageCount, None)
    VirtualMemorySizeInBytes = property(get_VirtualMemorySizeInBytes, None)
    WorkingSetSizeInBytes = property(get_WorkingSetSizeInBytes, None)
class ISystemCpuUsage(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.ISystemCpuUsage'
    _iid_ = Guid('{6037b3ac-02d6-4234-8362-7fe3adc81f5f}')
    @winrt_commethod(6)
    def GetReport(self) -> win32more.Windows.System.Diagnostics.SystemCpuUsageReport: ...
class ISystemCpuUsageReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.ISystemCpuUsageReport'
    _iid_ = Guid('{2c26d0b2-9483-4f62-ab57-82b29d9719b8}')
    @winrt_commethod(6)
    def get_KernelTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(7)
    def get_UserTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(8)
    def get_IdleTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    IdleTime = property(get_IdleTime, None)
    KernelTime = property(get_KernelTime, None)
    UserTime = property(get_UserTime, None)
class ISystemDiagnosticInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.ISystemDiagnosticInfo'
    _iid_ = Guid('{a290fe05-dff3-407f-9a1b-0b2b317ca800}')
    @winrt_commethod(6)
    def get_MemoryUsage(self) -> win32more.Windows.System.Diagnostics.SystemMemoryUsage: ...
    @winrt_commethod(7)
    def get_CpuUsage(self) -> win32more.Windows.System.Diagnostics.SystemCpuUsage: ...
    CpuUsage = property(get_CpuUsage, None)
    MemoryUsage = property(get_MemoryUsage, None)
class ISystemDiagnosticInfoStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.ISystemDiagnosticInfoStatics'
    _iid_ = Guid('{d404ac21-fc7d-45f0-9a3f-39203aed9f7e}')
    @winrt_commethod(6)
    def GetForCurrentSystem(self) -> win32more.Windows.System.Diagnostics.SystemDiagnosticInfo: ...
class ISystemDiagnosticInfoStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.ISystemDiagnosticInfoStatics2'
    _iid_ = Guid('{79ded189-6af9-4da9-a422-15f73255b3eb}')
    @winrt_commethod(6)
    def IsArchitectureSupported(self, type: win32more.Windows.System.ProcessorArchitecture) -> Boolean: ...
    @winrt_commethod(7)
    def get_PreferredArchitecture(self) -> win32more.Windows.System.ProcessorArchitecture: ...
    PreferredArchitecture = property(get_PreferredArchitecture, None)
class ISystemMemoryUsage(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.ISystemMemoryUsage'
    _iid_ = Guid('{17ffc595-1702-49cf-aa27-2f0a32591404}')
    @winrt_commethod(6)
    def GetReport(self) -> win32more.Windows.System.Diagnostics.SystemMemoryUsageReport: ...
class ISystemMemoryUsageReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.ISystemMemoryUsageReport'
    _iid_ = Guid('{38663c87-2a9f-403a-bd19-2cf3e8169500}')
    @winrt_commethod(6)
    def get_TotalPhysicalSizeInBytes(self) -> UInt64: ...
    @winrt_commethod(7)
    def get_AvailableSizeInBytes(self) -> UInt64: ...
    @winrt_commethod(8)
    def get_CommittedSizeInBytes(self) -> UInt64: ...
    AvailableSizeInBytes = property(get_AvailableSizeInBytes, None)
    CommittedSizeInBytes = property(get_CommittedSizeInBytes, None)
    TotalPhysicalSizeInBytes = property(get_TotalPhysicalSizeInBytes, None)
class ProcessCpuUsage(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Diagnostics.IProcessCpuUsage
    _classid_ = 'Windows.System.Diagnostics.ProcessCpuUsage'
    @winrt_mixinmethod
    def GetReport(self: win32more.Windows.System.Diagnostics.IProcessCpuUsage) -> win32more.Windows.System.Diagnostics.ProcessCpuUsageReport: ...
class ProcessCpuUsageReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Diagnostics.IProcessCpuUsageReport
    _classid_ = 'Windows.System.Diagnostics.ProcessCpuUsageReport'
    @winrt_mixinmethod
    def get_KernelTime(self: win32more.Windows.System.Diagnostics.IProcessCpuUsageReport) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_UserTime(self: win32more.Windows.System.Diagnostics.IProcessCpuUsageReport) -> win32more.Windows.Foundation.TimeSpan: ...
    KernelTime = property(get_KernelTime, None)
    UserTime = property(get_UserTime, None)
class ProcessDiagnosticInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Diagnostics.IProcessDiagnosticInfo
    _classid_ = 'Windows.System.Diagnostics.ProcessDiagnosticInfo'
    @winrt_mixinmethod
    def get_ProcessId(self: win32more.Windows.System.Diagnostics.IProcessDiagnosticInfo) -> UInt32: ...
    @winrt_mixinmethod
    def get_ExecutableFileName(self: win32more.Windows.System.Diagnostics.IProcessDiagnosticInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Parent(self: win32more.Windows.System.Diagnostics.IProcessDiagnosticInfo) -> win32more.Windows.System.Diagnostics.ProcessDiagnosticInfo: ...
    @winrt_mixinmethod
    def get_ProcessStartTime(self: win32more.Windows.System.Diagnostics.IProcessDiagnosticInfo) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def get_DiskUsage(self: win32more.Windows.System.Diagnostics.IProcessDiagnosticInfo) -> win32more.Windows.System.Diagnostics.ProcessDiskUsage: ...
    @winrt_mixinmethod
    def get_MemoryUsage(self: win32more.Windows.System.Diagnostics.IProcessDiagnosticInfo) -> win32more.Windows.System.Diagnostics.ProcessMemoryUsage: ...
    @winrt_mixinmethod
    def get_CpuUsage(self: win32more.Windows.System.Diagnostics.IProcessDiagnosticInfo) -> win32more.Windows.System.Diagnostics.ProcessCpuUsage: ...
    @winrt_mixinmethod
    def GetAppDiagnosticInfos(self: win32more.Windows.System.Diagnostics.IProcessDiagnosticInfo2) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.System.AppDiagnosticInfo]: ...
    @winrt_mixinmethod
    def get_IsPackaged(self: win32more.Windows.System.Diagnostics.IProcessDiagnosticInfo2) -> Boolean: ...
    @winrt_classmethod
    def TryGetForProcessId(cls: win32more.Windows.System.Diagnostics.IProcessDiagnosticInfoStatics2, processId: UInt32) -> win32more.Windows.System.Diagnostics.ProcessDiagnosticInfo: ...
    @winrt_classmethod
    def GetForProcesses(cls: win32more.Windows.System.Diagnostics.IProcessDiagnosticInfoStatics) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.System.Diagnostics.ProcessDiagnosticInfo]: ...
    @winrt_classmethod
    def GetForCurrentProcess(cls: win32more.Windows.System.Diagnostics.IProcessDiagnosticInfoStatics) -> win32more.Windows.System.Diagnostics.ProcessDiagnosticInfo: ...
    CpuUsage = property(get_CpuUsage, None)
    DiskUsage = property(get_DiskUsage, None)
    ExecutableFileName = property(get_ExecutableFileName, None)
    IsPackaged = property(get_IsPackaged, None)
    MemoryUsage = property(get_MemoryUsage, None)
    Parent = property(get_Parent, None)
    ProcessId = property(get_ProcessId, None)
    ProcessStartTime = property(get_ProcessStartTime, None)
class ProcessDiskUsage(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Diagnostics.IProcessDiskUsage
    _classid_ = 'Windows.System.Diagnostics.ProcessDiskUsage'
    @winrt_mixinmethod
    def GetReport(self: win32more.Windows.System.Diagnostics.IProcessDiskUsage) -> win32more.Windows.System.Diagnostics.ProcessDiskUsageReport: ...
class ProcessDiskUsageReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Diagnostics.IProcessDiskUsageReport
    _classid_ = 'Windows.System.Diagnostics.ProcessDiskUsageReport'
    @winrt_mixinmethod
    def get_ReadOperationCount(self: win32more.Windows.System.Diagnostics.IProcessDiskUsageReport) -> Int64: ...
    @winrt_mixinmethod
    def get_WriteOperationCount(self: win32more.Windows.System.Diagnostics.IProcessDiskUsageReport) -> Int64: ...
    @winrt_mixinmethod
    def get_OtherOperationCount(self: win32more.Windows.System.Diagnostics.IProcessDiskUsageReport) -> Int64: ...
    @winrt_mixinmethod
    def get_BytesReadCount(self: win32more.Windows.System.Diagnostics.IProcessDiskUsageReport) -> Int64: ...
    @winrt_mixinmethod
    def get_BytesWrittenCount(self: win32more.Windows.System.Diagnostics.IProcessDiskUsageReport) -> Int64: ...
    @winrt_mixinmethod
    def get_OtherBytesCount(self: win32more.Windows.System.Diagnostics.IProcessDiskUsageReport) -> Int64: ...
    BytesReadCount = property(get_BytesReadCount, None)
    BytesWrittenCount = property(get_BytesWrittenCount, None)
    OtherBytesCount = property(get_OtherBytesCount, None)
    OtherOperationCount = property(get_OtherOperationCount, None)
    ReadOperationCount = property(get_ReadOperationCount, None)
    WriteOperationCount = property(get_WriteOperationCount, None)
class ProcessMemoryUsage(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Diagnostics.IProcessMemoryUsage
    _classid_ = 'Windows.System.Diagnostics.ProcessMemoryUsage'
    @winrt_mixinmethod
    def GetReport(self: win32more.Windows.System.Diagnostics.IProcessMemoryUsage) -> win32more.Windows.System.Diagnostics.ProcessMemoryUsageReport: ...
class ProcessMemoryUsageReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Diagnostics.IProcessMemoryUsageReport
    _classid_ = 'Windows.System.Diagnostics.ProcessMemoryUsageReport'
    @winrt_mixinmethod
    def get_NonPagedPoolSizeInBytes(self: win32more.Windows.System.Diagnostics.IProcessMemoryUsageReport) -> UInt64: ...
    @winrt_mixinmethod
    def get_PageFaultCount(self: win32more.Windows.System.Diagnostics.IProcessMemoryUsageReport) -> UInt32: ...
    @winrt_mixinmethod
    def get_PageFileSizeInBytes(self: win32more.Windows.System.Diagnostics.IProcessMemoryUsageReport) -> UInt64: ...
    @winrt_mixinmethod
    def get_PagedPoolSizeInBytes(self: win32more.Windows.System.Diagnostics.IProcessMemoryUsageReport) -> UInt64: ...
    @winrt_mixinmethod
    def get_PeakNonPagedPoolSizeInBytes(self: win32more.Windows.System.Diagnostics.IProcessMemoryUsageReport) -> UInt64: ...
    @winrt_mixinmethod
    def get_PeakPageFileSizeInBytes(self: win32more.Windows.System.Diagnostics.IProcessMemoryUsageReport) -> UInt64: ...
    @winrt_mixinmethod
    def get_PeakPagedPoolSizeInBytes(self: win32more.Windows.System.Diagnostics.IProcessMemoryUsageReport) -> UInt64: ...
    @winrt_mixinmethod
    def get_PeakVirtualMemorySizeInBytes(self: win32more.Windows.System.Diagnostics.IProcessMemoryUsageReport) -> UInt64: ...
    @winrt_mixinmethod
    def get_PeakWorkingSetSizeInBytes(self: win32more.Windows.System.Diagnostics.IProcessMemoryUsageReport) -> UInt64: ...
    @winrt_mixinmethod
    def get_PrivatePageCount(self: win32more.Windows.System.Diagnostics.IProcessMemoryUsageReport) -> UInt64: ...
    @winrt_mixinmethod
    def get_VirtualMemorySizeInBytes(self: win32more.Windows.System.Diagnostics.IProcessMemoryUsageReport) -> UInt64: ...
    @winrt_mixinmethod
    def get_WorkingSetSizeInBytes(self: win32more.Windows.System.Diagnostics.IProcessMemoryUsageReport) -> UInt64: ...
    NonPagedPoolSizeInBytes = property(get_NonPagedPoolSizeInBytes, None)
    PageFaultCount = property(get_PageFaultCount, None)
    PageFileSizeInBytes = property(get_PageFileSizeInBytes, None)
    PagedPoolSizeInBytes = property(get_PagedPoolSizeInBytes, None)
    PeakNonPagedPoolSizeInBytes = property(get_PeakNonPagedPoolSizeInBytes, None)
    PeakPageFileSizeInBytes = property(get_PeakPageFileSizeInBytes, None)
    PeakPagedPoolSizeInBytes = property(get_PeakPagedPoolSizeInBytes, None)
    PeakVirtualMemorySizeInBytes = property(get_PeakVirtualMemorySizeInBytes, None)
    PeakWorkingSetSizeInBytes = property(get_PeakWorkingSetSizeInBytes, None)
    PrivatePageCount = property(get_PrivatePageCount, None)
    VirtualMemorySizeInBytes = property(get_VirtualMemorySizeInBytes, None)
    WorkingSetSizeInBytes = property(get_WorkingSetSizeInBytes, None)
class SystemCpuUsage(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Diagnostics.ISystemCpuUsage
    _classid_ = 'Windows.System.Diagnostics.SystemCpuUsage'
    @winrt_mixinmethod
    def GetReport(self: win32more.Windows.System.Diagnostics.ISystemCpuUsage) -> win32more.Windows.System.Diagnostics.SystemCpuUsageReport: ...
class SystemCpuUsageReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Diagnostics.ISystemCpuUsageReport
    _classid_ = 'Windows.System.Diagnostics.SystemCpuUsageReport'
    @winrt_mixinmethod
    def get_KernelTime(self: win32more.Windows.System.Diagnostics.ISystemCpuUsageReport) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_UserTime(self: win32more.Windows.System.Diagnostics.ISystemCpuUsageReport) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_IdleTime(self: win32more.Windows.System.Diagnostics.ISystemCpuUsageReport) -> win32more.Windows.Foundation.TimeSpan: ...
    IdleTime = property(get_IdleTime, None)
    KernelTime = property(get_KernelTime, None)
    UserTime = property(get_UserTime, None)
class _SystemDiagnosticInfo_Meta_(ComPtr.__class__):
    pass
class SystemDiagnosticInfo(ComPtr, metaclass=_SystemDiagnosticInfo_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Diagnostics.ISystemDiagnosticInfo
    _classid_ = 'Windows.System.Diagnostics.SystemDiagnosticInfo'
    @winrt_mixinmethod
    def get_MemoryUsage(self: win32more.Windows.System.Diagnostics.ISystemDiagnosticInfo) -> win32more.Windows.System.Diagnostics.SystemMemoryUsage: ...
    @winrt_mixinmethod
    def get_CpuUsage(self: win32more.Windows.System.Diagnostics.ISystemDiagnosticInfo) -> win32more.Windows.System.Diagnostics.SystemCpuUsage: ...
    @winrt_classmethod
    def IsArchitectureSupported(cls: win32more.Windows.System.Diagnostics.ISystemDiagnosticInfoStatics2, type: win32more.Windows.System.ProcessorArchitecture) -> Boolean: ...
    @winrt_classmethod
    def get_PreferredArchitecture(cls: win32more.Windows.System.Diagnostics.ISystemDiagnosticInfoStatics2) -> win32more.Windows.System.ProcessorArchitecture: ...
    @winrt_classmethod
    def GetForCurrentSystem(cls: win32more.Windows.System.Diagnostics.ISystemDiagnosticInfoStatics) -> win32more.Windows.System.Diagnostics.SystemDiagnosticInfo: ...
    CpuUsage = property(get_CpuUsage, None)
    MemoryUsage = property(get_MemoryUsage, None)
    _SystemDiagnosticInfo_Meta_.PreferredArchitecture = property(get_PreferredArchitecture, None)
class SystemMemoryUsage(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Diagnostics.ISystemMemoryUsage
    _classid_ = 'Windows.System.Diagnostics.SystemMemoryUsage'
    @winrt_mixinmethod
    def GetReport(self: win32more.Windows.System.Diagnostics.ISystemMemoryUsage) -> win32more.Windows.System.Diagnostics.SystemMemoryUsageReport: ...
class SystemMemoryUsageReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Diagnostics.ISystemMemoryUsageReport
    _classid_ = 'Windows.System.Diagnostics.SystemMemoryUsageReport'
    @winrt_mixinmethod
    def get_TotalPhysicalSizeInBytes(self: win32more.Windows.System.Diagnostics.ISystemMemoryUsageReport) -> UInt64: ...
    @winrt_mixinmethod
    def get_AvailableSizeInBytes(self: win32more.Windows.System.Diagnostics.ISystemMemoryUsageReport) -> UInt64: ...
    @winrt_mixinmethod
    def get_CommittedSizeInBytes(self: win32more.Windows.System.Diagnostics.ISystemMemoryUsageReport) -> UInt64: ...
    AvailableSizeInBytes = property(get_AvailableSizeInBytes, None)
    CommittedSizeInBytes = property(get_CommittedSizeInBytes, None)
    TotalPhysicalSizeInBytes = property(get_TotalPhysicalSizeInBytes, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.CompositionSwapchain
import win32more.Windows.Win32.Graphics.Dxgi.Common
import win32more.Windows.Win32.System.Com
@winfunctype('dcomp.dll')
def CreatePresentationFactory(d3dDevice: win32more.Windows.Win32.System.Com.IUnknown, riid: POINTER(Guid), presentationFactory: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class CompositionFrameDisplayInstance(Structure):
    displayAdapterLUID: win32more.Windows.Win32.Foundation.LUID
    displayVidPnSourceId: UInt32
    displayUniqueId: UInt32
    renderAdapterLUID: win32more.Windows.Win32.Foundation.LUID
    instanceKind: win32more.Windows.Win32.Graphics.CompositionSwapchain.CompositionFrameInstanceKind
    finalTransform: win32more.Windows.Win32.Graphics.CompositionSwapchain.PresentationTransform
    requiredCrossAdapterCopy: Byte
    colorSpace: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_COLOR_SPACE_TYPE
CompositionFrameInstanceKind = Int32
CompositionFrameInstanceKind_ComposedOnScreen: win32more.Windows.Win32.Graphics.CompositionSwapchain.CompositionFrameInstanceKind = 0
CompositionFrameInstanceKind_ScanoutOnScreen: win32more.Windows.Win32.Graphics.CompositionSwapchain.CompositionFrameInstanceKind = 1
CompositionFrameInstanceKind_ComposedToIntermediate: win32more.Windows.Win32.Graphics.CompositionSwapchain.CompositionFrameInstanceKind = 2
class ICompositionFramePresentStatistics(ComPtr):
    extends: win32more.Windows.Win32.Graphics.CompositionSwapchain.IPresentStatistics
    _iid_ = Guid('{ab41d127-c101-4c0a-911d-f9f2e9d08e64}')
    @commethod(5)
    def GetContentTag(self) -> UIntPtr: ...
    @commethod(6)
    def GetCompositionFrameId(self) -> UInt64: ...
    @commethod(7)
    def GetDisplayInstanceArray(self, displayInstanceArrayCount: POINTER(UInt32), displayInstanceArray: POINTER(POINTER(win32more.Windows.Win32.Graphics.CompositionSwapchain.CompositionFrameDisplayInstance))) -> Void: ...
class IIndependentFlipFramePresentStatistics(ComPtr):
    extends: win32more.Windows.Win32.Graphics.CompositionSwapchain.IPresentStatistics
    _iid_ = Guid('{8c93be27-ad94-4da0-8fd4-2413132d124e}')
    @commethod(5)
    def GetOutputAdapterLUID(self) -> win32more.Windows.Win32.Foundation.LUID: ...
    @commethod(6)
    def GetOutputVidPnSourceId(self) -> UInt32: ...
    @commethod(7)
    def GetContentTag(self) -> UIntPtr: ...
    @commethod(8)
    def GetDisplayedTime(self) -> win32more.Windows.Win32.Graphics.CompositionSwapchain.SystemInterruptTime: ...
    @commethod(9)
    def GetPresentDuration(self) -> win32more.Windows.Win32.Graphics.CompositionSwapchain.SystemInterruptTime: ...
class IPresentStatistics(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b44b8bda-7282-495d-9dd7-ceadd8b4bb86}')
    @commethod(3)
    def GetPresentId(self) -> UInt64: ...
    @commethod(4)
    def GetKind(self) -> win32more.Windows.Win32.Graphics.CompositionSwapchain.PresentStatisticsKind: ...
class IPresentStatusPresentStatistics(ComPtr):
    extends: win32more.Windows.Win32.Graphics.CompositionSwapchain.IPresentStatistics
    _iid_ = Guid('{c9ed2a41-79cb-435e-964e-c8553055420c}')
    @commethod(5)
    def GetCompositionFrameId(self) -> UInt64: ...
    @commethod(6)
    def GetPresentStatus(self) -> win32more.Windows.Win32.Graphics.CompositionSwapchain.PresentStatus: ...
class IPresentationBuffer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{2e217d3a-5abb-4138-9a13-a775593c89ca}')
    @commethod(3)
    def GetAvailableEvent(self, availableEventHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def IsAvailable(self, isAvailable: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPresentationContent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5668bb79-3d8e-415c-b215-f38020f2d252}')
    @commethod(3)
    def SetTag(self, tag: UIntPtr) -> Void: ...
class IPresentationFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8fb37b58-1d74-4f64-a49c-1f97a80a2ec0}')
    @commethod(3)
    def IsPresentationSupported(self) -> Byte: ...
    @commethod(4)
    def IsPresentationSupportedWithIndependentFlip(self) -> Byte: ...
    @commethod(5)
    def CreatePresentationManager(self, ppPresentationManager: POINTER(win32more.Windows.Win32.Graphics.CompositionSwapchain.IPresentationManager)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPresentationManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{fb562f82-6292-470a-88b1-843661e7f20c}')
    @commethod(3)
    def AddBufferFromResource(self, resource: win32more.Windows.Win32.System.Com.IUnknown, presentationBuffer: POINTER(win32more.Windows.Win32.Graphics.CompositionSwapchain.IPresentationBuffer)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreatePresentationSurface(self, compositionSurfaceHandle: win32more.Windows.Win32.Foundation.HANDLE, presentationSurface: POINTER(win32more.Windows.Win32.Graphics.CompositionSwapchain.IPresentationSurface)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetNextPresentId(self) -> UInt64: ...
    @commethod(6)
    def SetTargetTime(self, targetTime: win32more.Windows.Win32.Graphics.CompositionSwapchain.SystemInterruptTime) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetPreferredPresentDuration(self, preferredDuration: win32more.Windows.Win32.Graphics.CompositionSwapchain.SystemInterruptTime, deviationTolerance: win32more.Windows.Win32.Graphics.CompositionSwapchain.SystemInterruptTime) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def ForceVSyncInterrupt(self, forceVsyncInterrupt: Byte) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Present(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetPresentRetiringFence(self, riid: POINTER(Guid), fence: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CancelPresentsFrom(self, presentIdToCancelFrom: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetLostEvent(self, lostEventHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetPresentStatisticsAvailableEvent(self, presentStatisticsAvailableEventHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def EnablePresentStatisticsKind(self, presentStatisticsKind: win32more.Windows.Win32.Graphics.CompositionSwapchain.PresentStatisticsKind, enabled: Byte) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetNextPresentStatistics(self, nextPresentStatistics: POINTER(win32more.Windows.Win32.Graphics.CompositionSwapchain.IPresentStatistics)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPresentationSurface(ComPtr):
    extends: win32more.Windows.Win32.Graphics.CompositionSwapchain.IPresentationContent
    _iid_ = Guid('{956710fb-ea40-4eba-a3eb-4375a0eb4edc}')
    @commethod(4)
    def SetBuffer(self, presentationBuffer: win32more.Windows.Win32.Graphics.CompositionSwapchain.IPresentationBuffer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetColorSpace(self, colorSpace: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_COLOR_SPACE_TYPE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetAlphaMode(self, alphaMode: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_ALPHA_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetSourceRect(self, sourceRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetTransform(self, transform: POINTER(win32more.Windows.Win32.Graphics.CompositionSwapchain.PresentationTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def RestrictToOutput(self, output: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetDisableReadback(self, value: Byte) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetLetterboxingMargins(self, leftLetterboxSize: Single, topLetterboxSize: Single, rightLetterboxSize: Single, bottomLetterboxSize: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
PresentStatisticsKind = Int32
PresentStatisticsKind_PresentStatus: win32more.Windows.Win32.Graphics.CompositionSwapchain.PresentStatisticsKind = 1
PresentStatisticsKind_CompositionFrame: win32more.Windows.Win32.Graphics.CompositionSwapchain.PresentStatisticsKind = 2
PresentStatisticsKind_IndependentFlipFrame: win32more.Windows.Win32.Graphics.CompositionSwapchain.PresentStatisticsKind = 3
PresentStatus = Int32
PresentStatus_Queued: win32more.Windows.Win32.Graphics.CompositionSwapchain.PresentStatus = 0
PresentStatus_Skipped: win32more.Windows.Win32.Graphics.CompositionSwapchain.PresentStatus = 1
PresentStatus_Canceled: win32more.Windows.Win32.Graphics.CompositionSwapchain.PresentStatus = 2
class PresentationTransform(Structure):
    M11: Single
    M12: Single
    M21: Single
    M22: Single
    M31: Single
    M32: Single
class SystemInterruptTime(Structure):
    value: UInt64


make_ready(__name__)
